Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3612)

Unified Diff: cc/CCResourceProvider.h

Issue 11074009: cc: Remove LayerTextureUpdater::Texture::updateRect() callback. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « cc/CCPrioritizedTexture.cpp ('k') | cc/CCResourceProvider.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: cc/CCResourceProvider.h
diff --git a/cc/CCResourceProvider.h b/cc/CCResourceProvider.h
index 1e08882bec6f5900e342e602d9f99cc5b03ec97c..37bf03f06c6be9ec9f93d74d4e6c50c915f63e9f 100644
--- a/cc/CCResourceProvider.h
+++ b/cc/CCResourceProvider.h
@@ -95,9 +95,12 @@ public:
// Deletes all resources owned by a given pool.
void deleteOwnedResources(int pool);
// Upload data from image, copying sourceRect (in image) into destRect (in the resource).
void upload(ResourceId, const uint8_t* image, const IntRect& imageRect, const IntRect& sourceRect, const IntSize& destOffset);
+ // Playback contents from picture, painting sourceRect (in picture) to destOffset (in the resource).
+ void acceleratedUpdate(ResourceId, SkPicture*, const IntRect& pictureRect, const IntRect& sourceRect, const IntSize& destOffset);
piman 2012/10/08 18:33:42 This feels a bit out of place. I'd rather have thi
reveman 2012/10/08 19:45:02 Ok, maybe it belongs in CCTextureUpdateController.
+
// Flush all context operations, kicking uploads and ensuring ordering with
// respect to other contexts.
void flush();
@@ -95,9 +95,12 @@ public:
// Deletes all resources owned by a given pool.
void deleteOwnedResources(int pool);
- // Upload data from image, copying sourceRect (in image) into destRect (in the resource).
+ // Upload data from image, copying sourceRect (in image) to destOffset (in the resource).
void upload(ResourceId, const uint8_t* image, const IntRect& imageRect, const IntRect& sourceRect, const IntSize& destOffset);
« no previous file with comments | « cc/CCPrioritizedTexture.cpp ('k') | cc/CCResourceProvider.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698